@@ -207,12 +207,21 @@ def _find_identity_resource(identity_client_manager, name_or_id,
                                                 name_or_id, **kwargs)
         if identity_resource is not None:
             return identity_resource
-    except identity_exc.Forbidden:
+    except exceptions.Forbidden:
         pass
 
     return resource_type(None, {'id': name_or_id, 'name': name_or_id})
 
 
+def get_immutable_options(parsed_args):
+    options = {}
+    if parsed_args.immutable:
+        options['immutable'] = True
+    if parsed_args.no_immutable:
+        options['immutable'] = False
+    return options
+
+
 def add_user_domain_option_to_parser(parser):
     parser.add_argument(
         '--user-domain',
@@ -233,13 +242,13 @@ def add_group_domain_option_to_parser(parser):
     )
 
 
-def add_project_domain_option_to_parser(parser):
+def add_project_domain_option_to_parser(parser, enhance_help=lambda _h: _h):
     parser.add_argument(
         '--project-domain',
         metavar='<project-domain>',
-        help=_('Domain the project belongs to (name or ID). '
-               'This can be used in case collisions between project names '
-               'exist.'),
+        help=enhance_help(_('Domain the project belongs to (name or ID). This '
+                            'can be used in case collisions between project '
+                            'names exist.')),
     )
 
 
@@ -261,3 +270,18 @@ def add_inherited_option_to_parser(parser):
         help=_('Specifies if the role grant is inheritable to the sub '
                'projects'),
     )
+
+
+def add_resource_option_to_parser(parser):
+    enable_group = parser.add_mutually_exclusive_group()
+    enable_group.add_argument(
+        '--immutable',
+        action='store_true',
+        help=_('Make resource immutable. An immutable project may not '
+               'be deleted or modified except to remove the immutable flag'),
+    )
+    enable_group.add_argument(
+        '--no-immutable',
+        action='store_true',
+        help=_('Make resource mutable (default)'),
+    )
