@@ -13,7 +13,7 @@
 #   under the License.
 #
 
-import mock
+from unittest import mock
 
 from osc_lib import exceptions
 from osc_lib import utils
