@@ -15,10 +15,9 @@ import argparse
 import copy
 from random import choice
 from random import randint
+from unittest import mock
 import uuid
 
-import mock
-
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes_v3
 from openstackclient.tests.unit import utils
@@ -639,6 +638,7 @@ class FakePort(object):
             'security_group_ids': [],
             'status': 'ACTIVE',
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
+            'qos_network_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
             'qos_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
             'tags': [],
             'uplink_status_propagation': False,
@@ -1227,6 +1227,7 @@ class FakeSecurityGroup(object):
             'id': 'security-group-id-' + uuid.uuid4().hex,
             'name': 'security-group-name-' + uuid.uuid4().hex,
             'description': 'security-group-description-' + uuid.uuid4().hex,
+            'stateful': True,
             'project_id': 'project-id-' + uuid.uuid4().hex,
             'security_group_rules': [],
             'tags': []
@@ -1832,7 +1833,7 @@ class FakeFloatingIPPortForwarding(object):
         """
         attrs = attrs or {}
         floatingip_id = (
-            attrs.get('floatingip_id') or'floating-ip-id-' + uuid.uuid4().hex
+            attrs.get('floatingip_id') or 'floating-ip-id-' + uuid.uuid4().hex
         )
         # Set default attributes.
         port_forwarding_attrs = {
@@ -1843,6 +1844,7 @@ class FakeFloatingIPPortForwarding(object):
             'internal_port': randint(1, 65535),
             'external_port': randint(1, 65535),
             'protocol': 'tcp',
+            'description': 'some description',
         }
 
         # Overwrite default attributes.
