@@ -12,9 +12,9 @@
 #
 
 import argparse
+from unittest import mock
+from unittest.mock import call
 
-import mock
-from mock import call
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
 from osc_lib import utils
@@ -61,6 +61,7 @@ class TestPort(network_fakes.TestNetworkV2):
             'network_id',
             'port_security_enabled',
             'project_id',
+            'qos_network_policy_id',
             'qos_policy_id',
             'security_group_ids',
             'status',
@@ -91,6 +92,7 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.network_id,
             fake_port.port_security_enabled,
             fake_port.project_id,
+            fake_port.qos_network_policy_id,
             fake_port.qos_policy_id,
             format_columns.ListColumn(fake_port.security_group_ids),
             fake_port.status,
@@ -1052,6 +1054,22 @@ class TestListPort(TestPort):
         self.assertEqual(self.columns_long, columns)
         self.assertListItemEqual(self.data_long, list(data))
 
+    def test_port_list_host(self):
+        arglist = [
+            '--host', 'foobar',
+        ]
+        verifylist = [
+            ('host', 'foobar'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'binding:host_id': 'foobar'}
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertListItemEqual(self.data, list(data))
+
     def test_port_list_project(self):
         project = identity_fakes.FakeProject.create_one_project()
         self.projects_mock.get.return_value = project
