@@ -11,8 +11,8 @@
 #   under the License.
 #
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib import exceptions
 
@@ -49,6 +49,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
         'name',
         'project_id',
         'rules',
+        'stateful',
         'tags',
     )
 
@@ -58,6 +59,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
         _security_group.name,
         _security_group.project_id,
         security_group.NetworkSecurityGroupRulesColumn([]),
+        _security_group.stateful,
         _security_group.tags,
     )
 
@@ -101,6 +103,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
             '--description', self._security_group.description,
             '--project', self.project.name,
             '--project-domain', self.domain.name,
+            '--stateful',
             self._security_group.name,
         ]
         verifylist = [
@@ -108,6 +111,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
             ('name', self._security_group.name),
             ('project', self.project.name),
             ('project_domain', self.domain.name),
+            ('stateful', self._security_group.stateful),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -115,6 +119,7 @@ class TestCreateSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         self.network.create_security_group.assert_called_once_with(**{
             'description': self._security_group.description,
+            'stateful': self._security_group.stateful,
             'name': self._security_group.name,
             'tenant_id': self.project.id,
         })
@@ -285,7 +290,8 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.security_groups.assert_called_once_with()
+        self.network.security_groups.assert_called_once_with(
+            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE)
         self.assertEqual(self.columns, columns)
         self.assertListItemEqual(self.data, list(data))
 
@@ -300,7 +306,8 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.security_groups.assert_called_once_with()
+        self.network.security_groups.assert_called_once_with(
+            fields=security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE)
         self.assertEqual(self.columns, columns)
         self.assertListItemEqual(self.data, list(data))
 
@@ -316,7 +323,9 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'tenant_id': project.id, 'project_id': project.id,
+            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
 
         self.network.security_groups.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -336,7 +345,9 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'tenant_id': project.id, 'project_id': project.id,
+            'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
 
         self.network.security_groups.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -362,7 +373,8 @@ class TestListSecurityGroupNetwork(TestSecurityGroupNetwork):
             **{'tags': 'red,blue',
                'any_tags': 'red,green',
                'not_tags': 'orange,yellow',
-               'not_any_tags': 'black,white'}
+               'not_any_tags': 'black,white',
+               'fields': security_group.ListSecurityGroup.FIELDS_TO_RETRIEVE}
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
@@ -414,11 +426,13 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
         arglist = [
             '--name', new_name,
             '--description', new_description,
+            '--stateful',
             self._security_group.name,
         ]
         verifylist = [
             ('description', new_description),
             ('group', self._security_group.name),
+            ('stateful', self._security_group.stateful),
             ('name', new_name),
         ]
 
@@ -428,6 +442,7 @@ class TestSetSecurityGroupNetwork(TestSecurityGroupNetwork):
         attrs = {
             'description': new_description,
             'name': new_name,
+            'stateful': True,
         }
         self.network.update_security_group.assert_called_once_with(
             self._security_group,
@@ -482,6 +497,7 @@ class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
         'name',
         'project_id',
         'rules',
+        'stateful',
         'tags',
     )
 
@@ -492,6 +508,7 @@ class TestShowSecurityGroupNetwork(TestSecurityGroupNetwork):
         _security_group.project_id,
         security_group.NetworkSecurityGroupRulesColumn(
             [_security_group_rule._info]),
+        _security_group.stateful,
         _security_group.tags,
     )
 
